@@ -7,7 +7,7 @@ use Carp;
 use vars qw(@ISA $VERSION);
 @ISA = qw(Boulder::Stream);
 
-$VERSION = 1.05;
+$VERSION = 1.06;
 
 # Hard-coded defaults - must modify for your site
 use constant YANK            =>  '/usr/local/bin/yank';
@@ -823,8 +823,13 @@ sub parse {
     $key = $keyword if $keyword;
   }
   
-  my($sequence) = $record=~/\nORIGIN\s+(.+)\\?\\?/s;
-  $sequence=~s/[\s0-9-]+//g;  # remove white space
+  my($sequence) = $record=~/\nORIGIN\n(.+)\\?\\?/s;
+#  $sequence=~s/[\s0-9-]+//g;  # remove white space and numbers
+#  $sequence =~ s/^\s*\d+\s//mg;  # remove leading numbers and whitespace
+#  $sequence =~ s/(\S{1,10}) /$1/g; # remove spacer
+  $sequence =~ s/^.{9,10}//mg;    # remove leading numbers and whitespace
+  $sequence =~ s/(.{10}) /$1/g; # remove spacers
+  $sequence =~ s/\n//g;
   $self->_addToStone('Sequence',$sequence,$s,\%ok);
   return $s;
 }
